@@ -14,8 +14,8 @@ def create_log_path(log_path):
         os.makedirs(log_path)
 
 def create_app(config):
-    create_log_path(config.logger_dict['path'])
-    logging.config.dictConfig(config.logger_dict)
+    create_log_path(config.LOGGER_CONFIG['path'])
+    logging.config.dictConfig(config.LOGGER_CONFIG)
     global app
     app = GtFlask(__name__)
     app.logger.info('---基础框架正在初始化中, 框架版本:V{}---'.format(VERSION))
@@ -26,8 +26,8 @@ def create_app(config):
     db = SQLAlchemy(app)
     app.db = db
 
-    if config.modules:
-        load_modules(config.modules)
+    if config.MODULES:
+        load_modules(config.MODULES)
     
     return app
 
